"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Highlight = void 0;
var operations_1 = require("./graph/generated/operations");
var error_stack_parser_1 = __importDefault(require("error-stack-parser"));
var graphql_request_1 = require("graphql-request");
var Highlight = /** @class */ (function () {
    function Highlight(options) {
        var _this = this;
        this.FLUSH_TIMEOUT = 10;
        this.errors = [];
        this._backendUrl = options.backendUrl || 'https://pub.highlight.run';
        var client = new graphql_request_1.GraphQLClient(this._backendUrl, {
            headers: {},
        });
        this._graphqlSdk = (0, operations_1.getSdk)(client);
        this._intervalFunction = setInterval(function () { return _this.flush(); }, this.FLUSH_TIMEOUT * 1000);
    }
    Highlight.prototype.consumeCustomError = function (error, secureSessionId, requestId) {
        var res = [];
        try {
            res = error_stack_parser_1.default.parse(error);
        }
        catch (_a) { }
        this.errors.push({
            event: error.message
                ? "".concat(error.name, ": ").concat(error.message)
                : "".concat(error.name),
            request_id: requestId,
            session_secure_id: secureSessionId,
            source: '',
            stackTrace: JSON.stringify(res),
            timestamp: new Date().toISOString(),
            type: 'BACKEND',
            url: '',
        });
    };
    Highlight.prototype.flush = function () {
        if (this.errors.length === 0) {
            return;
        }
        var variables = {
            errors: this.errors,
        };
        this.errors = [];
        this._graphqlSdk
            .PushBackendPayload(variables)
            .then(function () { })
            .catch(function (e) {
            console.log('highlight-node error: ', e);
        });
    };
    return Highlight;
}());
exports.Highlight = Highlight;
