import { getSdk, } from './graph/generated/operations';
import ErrorStackParser from 'error-stack-parser';
import { GraphQLClient } from 'graphql-request';
var Highlight = /** @class */ (function () {
    function Highlight(options) {
        var _this = this;
        this.FLUSH_TIMEOUT = 10;
        this.errors = [];
        this._backendUrl = options.backendUrl || 'https://pub.highlight.run';
        var client = new GraphQLClient(this._backendUrl, {
            headers: {},
        });
        this._graphqlSdk = getSdk(client);
        this._intervalFunction = setInterval(function () { return _this.flush(); }, this.FLUSH_TIMEOUT * 1000);
    }
    Highlight.prototype.consumeCustomError = function (error, secureSessionId, requestId) {
        var res = [];
        try {
            res = ErrorStackParser.parse(error);
        }
        catch (_a) { }
        this.errors.push({
            event: error.message
                ? "".concat(error.name, ": ").concat(error.message)
                : "".concat(error.name),
            request_id: requestId,
            session_secure_id: secureSessionId,
            source: '',
            stackTrace: JSON.stringify(res),
            timestamp: new Date().toISOString(),
            type: 'BACKEND',
            url: '',
        });
    };
    Highlight.prototype.flush = function () {
        if (this.errors.length === 0) {
            return;
        }
        var variables = {
            errors: this.errors,
        };
        this.errors = [];
        this._graphqlSdk
            .PushBackendPayload(variables)
            .then(function () { })
            .catch(function (e) {
            console.log('highlight-node error: ', e);
        });
    };
    return Highlight;
}());
export { Highlight };
